@@ -328,6 +328,21 @@ class ExtraFilesFromPaths(ExtraFiles):
     may be binary then this alternative is necessary.
     """
 
+class ExtraControlBinaryFields(InfoElement):
+
+    name = 'extra_control_binary_fields'
+    description = """Any extra fields for the binary package in debian/control
+
+    If the backend needs to set extra fields in the binary section of
+    debian/control it can do so via this element. It should contain
+    newline-separated fields, using the colon-separated format, e.g:
+
+        XB-Something: foo
+        XB-Something-else: bar
+
+    There should be no trailing newline.
+    """
+
 
 # The following are for 'binary'.
 
