@@ -19,6 +19,7 @@ from ..info_elements import (
     Description,
     Executable,
     ExplicitCopyright,
+    ExtraControlBinaryFields,
     ExtraFiles,
     ExtraFilesFromPaths,
     ExtraTargets,
@@ -477,6 +478,25 @@ class ControlTests(PackageFileTestCase):
             package_file.get_contents(),
             ControlStanzaHasField(1, "Description", description))
 
+    def test_get_contents_sets_any_extra_binary_fields(self):
+        extra_field_name1 = "X-{}".format(self.getUniqueString())
+        extra_field_name2 = "X-{}".format(self.getUniqueString())
+        extra_field_value1 = self.getUniqueString()
+        extra_field_value2 = self.getUniqueString()
+        extra_fields = "{0}: {1}\n{2}: {3}".format(
+            extra_field_name1, extra_field_value1,
+            extra_field_name2, extra_field_value2)
+        args = {ExtraControlBinaryFields.name: extra_fields}
+        package_file = self.get_object(args)
+        self.assertThat(
+            package_file.get_contents(),
+            ControlStanzaHasField(1, extra_field_name1,
+                extra_field_value1))
+        self.assertThat(
+            package_file.get_contents(),
+            ControlStanzaHasField(1, extra_field_name2,
+                extra_field_value2))
+
 
 class SourceFormatTests(PackageFileTestCase):
 
