@@ -2,7 +2,7 @@ import pickle
 
 from testtools import TestCase
 
-from pkgme.run_script import (
+from ..run_script import (
     ScriptFailed,
     ScriptUserError,
     )
