@@ -13,18 +13,12 @@ from testtools.matchers import (
     DirExists,
     Not,
     )
+from treeshape import FileTree
 
-from pkgme.backend import (
-    BackendSelector,
-    StaticBackend,
-    )
-from pkgme.bin.main import get_all_info
-from pkgme.info_elements import (
-    PackageName,
-    )
-from pkgme.project_info import DictInfo
-from pkgme.testing import (
-    TempdirFixture,
+from ..api import (
+    get_all_info,
+    load_backends,
+    packaging_info_as_data,
     )
 
 
@@ -57,23 +51,21 @@ class ScriptTests(TestCase):
         self.assertEqual('', stderr.getvalue())
         return stdout.getvalue()
 
-    def create_marker_file(self, tempdir, prefix=None):
+    def create_marker_file(self, prefix=None):
         """Create the file that triggers the dummy backend for testing."""
         path = "is_pkgme_test"
         if prefix is not None:
             path = os.path.join(prefix, path)
-        tempdir.create_file(path, "")
+        return self.useFixture(FileTree({path: {}}))
 
     def test_writes_files(self):
-        tempdir = self.useFixture(TempdirFixture())
-        self.create_marker_file(tempdir)
+        tempdir = self.create_marker_file()
         self.run_script(tempdir.path)
-        self.assertThat(tempdir.abspath("debian"), DirExists())
+        self.assertThat(tempdir.join("debian"), DirExists())
 
     def test_builds_source_package(self):
-        tempdir = self.useFixture(TempdirFixture())
-        self.create_marker_file(tempdir, prefix="foo")
-        self.run_script(tempdir.abspath('foo'))
+        tempdir = self.create_marker_file(prefix="foo")
+        self.run_script(tempdir.join('foo'))
         self.assertThat(tempdir.path, DirContains(
             ["foo_0.0.0.orig.tar.gz",
              "foo_0.0.0.debian.tar.gz",
@@ -84,65 +76,30 @@ class ScriptTests(TestCase):
              ]))
 
     def test_nobuild_doesnt_builds_source_package(self):
-        tempdir = self.useFixture(TempdirFixture())
-        self.create_marker_file(tempdir, prefix="foo")
-        self.run_script(tempdir.abspath('foo'), ['--nobuild'])
+        tempdir = self.create_marker_file(prefix="foo")
+        self.run_script(tempdir.join('foo'), ['--nobuild'])
         self.assertThat(tempdir.path, DirContains(["foo"]))
 
     def test_which_backends(self):
-        tempdir = self.useFixture(TempdirFixture())
-        self.create_marker_file(tempdir)
+        tempdir = self.create_marker_file()
         output = self.run_script(tempdir.path, ['--which-backends'])
         self.assertEqual('dummy (100)\n', output)
-        self.assertThat(tempdir.abspath("debian"), Not(DirExists()))
+        self.assertThat(tempdir.join("debian"), Not(DirExists()))
 
     def test_dump(self):
-        tempdir = self.useFixture(TempdirFixture())
-        self.create_marker_file(tempdir)
-        all_info = get_all_info(tempdir.path)
-        clean_info = json.loads(json.dumps(all_info))
+        tempdir = self.create_marker_file()
+        all_info = get_all_info(tempdir.path, load_backends())
+        clean_info = packaging_info_as_data(all_info)
         output = self.run_script(tempdir.path, ['--dump'])
         self.assertEqual(clean_info, json.loads(output))
-        self.assertThat(tempdir.abspath("debian"), Not(DirExists()))
+        self.assertThat(tempdir.join("debian"), Not(DirExists()))
 
     def test_nosign(self):
-        tempdir = self.useFixture(TempdirFixture())
-        self.create_marker_file(tempdir, prefix='foo')
-        self.run_script(tempdir.abspath('foo'), ['--nosign'])
+        tempdir = self.create_marker_file(prefix='foo')
+        self.run_script(tempdir.join('foo'), ['--nosign'])
         changes_file = os.path.join(tempdir.path,
                                     "foo_0.0.0_source.changes")
         signature = open(changes_file)
         sig_text = signature.readlines()
         signature.close()
         self.assertNotIn(sig_text, "-----BEGIN PGP SIGNATURE-----\n")
-
-class GetAllInfoTests(TestCase):
-
-    def test_eligible_backends(self):
-        info = DictInfo({})
-        backend1 = StaticBackend(self.getUniqueString(), 5, info)
-        backend2 = StaticBackend(self.getUniqueString(), 10, info)
-        selector = BackendSelector([backend1, backend2])
-        path = self.getUniqueString()
-        info = get_all_info(path, selector)
-        self.assertEqual(
-            [(10, backend2.name), (5, backend1.name)], info['eligible_backends'])
-
-    def test_selected_backend(self):
-        info = DictInfo({})
-        backend1 = StaticBackend(self.getUniqueString(), 5, info)
-        backend2 = StaticBackend(self.getUniqueString(), 10, info)
-        selector = BackendSelector([backend1, backend2])
-        path = self.getUniqueString()
-        info = get_all_info(path, selector)
-        self.assertEqual(backend2.name, info['selected_backend'])
-
-    def test_all_info(self):
-        info = {PackageName.name: self.getUniqueString()}
-        backend = StaticBackend(self.getUniqueString(), 5, DictInfo(info))
-        selector = BackendSelector([backend])
-        path = self.getUniqueString()
-        all_info = get_all_info(path, selector)
-        del all_info['eligible_backends']
-        del all_info['selected_backend']
-        self.assertEqual(info, all_info)
